@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: balance.pl,v 1.3 2003/01/29 22:02:42 florian Exp $
+# $Id: balance.pl,v 1.4 2003/08/14 21:42:29 florian Exp $
 
 use Finance::Bank::PSK;
 
@@ -14,7 +14,8 @@ my $agent = Finance::Bank::PSK->new(
 	return_floats => 1,
 );
 
-my $result = $agent->check_balance;
+my $result  = $agent->check_balance;
+my $entries = $agent->get_entries;
 
 foreach my $account (@{$result->{accounts}}) {
         printf("%11s: %25s\n", $_->[0], $account->{$_->[1]})
@@ -38,3 +39,14 @@ foreach my $fund (@{$result->{funds}}) {
         printf("%11s: %25.2f\n", 'Saldo', $fund->{balance});
         print "\n";
 }
+
+if(scalar @$entries) {
+        printf("Buchungszeilen:\n\n");
+        foreach my $row (@$entries) {
+                $row->{text} =~ s/(.{50}).*/$1.../;
+
+                printf("%7s %5s %53s %9.2f\n",
+                        @{$row}{qw/nr value text amount/}
+                );
+        }
+}
